use crate::cli::FormatMode;
use crate::jira_config::JiraConfig;
use crate::types::issue::{display_issues_compact, display_issues_json, display_issues_pretty};

pub async fn exec(output: FormatMode, jql: &str) -> Result<(), Box<dyn std::error::Error>> {
    let config = JiraConfig::load().map_err(|e| format!("Configuration error: {}", e))?;
    if output != FormatMode::Json {
        println!("Searching for issues...");
    }

    let result = match crate::jql::run(&config, jql).await {
        Ok(x) => x,
        Err(reason) => {
            eprintln!("Error fetching issues: {}", reason);
            std::process::exit(1);
        }
    };

    match (output, result.issues.is_empty()) {
        (FormatMode::Pretty, false) => {
            display_issues_pretty(&result.issues)?;
            println!("Total issues: {}", result.total);
        }
        (FormatMode::Pretty, true) => {
            println!("No results found for query.");
        }
        (FormatMode::Json, false) => display_issues_json(&result.issues)?,
        (FormatMode::Json, true) => println!("[]"),
        (FormatMode::Compact, false) => display_issues_compact(&result.issues)?,
        (FormatMode::Compact, true) => {
            println!("No results found for query.");
        }
    }

    Ok(())
}
